@@ -104,7 +104,7 @@
 #' Regression weights can be computed in a matched or weighted sample by
 #' supplying a `matchit` or `weightit` object (from \pkg{MatchIt} or
 #' \pkg{WeightIt}, respectively) to the `obj` argument of `lmw()`.
-#' The estimand, base weights, and sampling weights (if any) will be taken from
+#' The estimand, focal group (if any), base weights, and sampling weights (if any) will be taken from
 #' the supplied object and used in the calculation of the implied regression
 #' weights, unless these have been supplied separately to `lmw()`. The
 #' `weights` component of the supplied object containing the matching or
@@ -201,7 +201,7 @@
 #' weights.
 #' @param dr.method the method used to incorporate the `base.weights` into
 #' a doubly-robust estimator. Can be one of `"WLS"` for weighted least
-#' squares or `"AIPW"` for augmented inverse probability weighting.
+#' squares (`"IPWRA"` is an allowable alias) or `"AIPW"` for augmented inverse probability weighting.
 #' Ignored when `base.weights` is `NULL`.
 #' @param obj a `matchit` or `weightit` object corresponding to the
 #' matched or weighted sample in which the implied outcome regression would
@@ -262,8 +262,7 @@
 #' `lmw` objects; [influence.lmw()] for influence measures;
 #' [lm()] for fitting standard regression models.
 #'
-#' @references Chattopadhyay, A., & Zubizarreta, J. R. (2022). On the implied
-#' weights of linear regression for causal inference. *Biometrika*, asac058. \doi{10.1093/biomet/asac058}
+#' @references Chattopadhyay, A., & Zubizarreta, J. R. (2023). On the implied weights of linear regression for causal inference. *Biometrika*, 110(3), 615–629. \doi{10.1093/biomet/asac058}
 #'
 #' @examples
 #' data("lalonde")
@@ -354,6 +353,8 @@ lmw <- function(formula, data = NULL, estimand = "ATE", method = "URI", treat =
                 contrast = NULL, focal = NULL) {
   call <- match.call()
 
+  chk::chk_string(method)
+  method <- toupper(method)
   method <- match_arg(method, c("URI", "MRI"))
 
   estimand <- process_estimand(estimand, target, obj)
@@ -380,7 +381,7 @@ lmw <- function(formula, data = NULL, estimand = "ATE", method = "URI", treat =
   #treat_contrast has levels re-ordered so contrast is first
   treat_contrast <- apply_contrast_to_treat(treat, contrast)
 
-  focal <- process_focal(focal, treat_contrast, estimand)
+  focal <- process_focal(focal, treat_contrast, estimand, obj)
 
   X_obj <- get_X_from_formula(formula, data, treat_contrast, method, estimand,
                               target, s.weights, target.weights, focal)
@@ -404,7 +405,7 @@ lmw <- function(formula, data = NULL, estimand = "ATE", method = "URI", treat =
 
   class(out) <- c("lmw_aipw"[!is.null(dr.method) && dr.method == "AIPW"],
                   "lmw_multi"[nlevels(treat) > 2], "lmw")
-  return(out)
+  out
 }
 
 #' @exportS3Method print lmw
@@ -442,4 +443,6 @@ print.lmw <- function(x, ...) {
     cat(sprintf(" - fixed effect: %s\n",
                 attr(x$fixef, "fixef_name")))
   }
+
+  invisible(x)
 }
